==> segatex_suite-1.4.tgz: segatex_suite-1.4/segatex_audit2allow.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXAUDIT2ALLOW_H
#define SEGATEXAUDIT2ALLOW_H

#include <qregexp.h>
#include <qdialog.h>
#include <qradiobutton.h>
#include <qtextedit.h>


class QLayout;
class QCheckBox;
class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;
class SegatexAudit2allowProcess;

class SegatexAudit2allow: public QDialog
{
	Q_OBJECT
public:
	SegatexAudit2allow(QWidget *parent = 0, const char *name = 0);
    
public slots:
signals:
protected:

private slots:
	void audit2allow_clicked();
	unsigned long getuid_uid_value();//unused
private:
	QRadioButton *auditRadioButton;
	QRadioButton *dmesgRadioButton;
	QCheckBox *lastreloadCheckBox;
	QCheckBox *requiresCheckBox;
	QCheckBox *referenceCheckBox;
	QCheckBox *verboseCheckBox;
	QCheckBox *explainCheckBox;
	QLineEdit *passwordLineEdit;
	QTextEdit *textEdit1;
	QPushButton *audit2allowButton;
	QPushButton *closeButton;
	SegatexAudit2allowProcess *selinux_audit2allow_process;
};

#endif

==> segatex_suite-2.1.tgz: segatex_suite-2.1/segatex_audit2allow.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXAUDIT2ALLOW_H
#define SEGATEXAUDIT2ALLOW_H

#include <qregexp.h>
#include <qdialog.h>
#include <qradiobutton.h>
#include <qtextedit.h>


class QLayout;
class QCheckBox;
class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;
class SegatexAudit2allowProcess;
class SegatexAudit2allowProcessE;
class SegatexAudit2allowProcessL;
class SegatexAudit2allowProcessR;
class SegatexAudit2allowProcessV;

class SegatexAudit2allow: public QDialog
{
	Q_OBJECT
public:
	SegatexAudit2allow(QWidget *parent = 0, const char *name = 0);
	SegatexAudit2allowProcess *selinux_audit2allow_process;
	SegatexAudit2allowProcessE *selinux_audit2allow_process_e;
	SegatexAudit2allowProcessL *selinux_audit2allow_process_l;
	SegatexAudit2allowProcessR *selinux_audit2allow_process_r;
	SegatexAudit2allowProcessV *selinux_audit2allow_process_v;
	SegatexAudit2allow *selinux_audit2allow_common_obj;
	int j;
public slots:
signals:
	void explainChecked();
	void lastreloadChecked();
	void referenceChecked();
	void verboseChecked();
protected:

private slots:
	void audit2allow_clicked();
	unsigned long getuid_uid_value();//unused
private:
	QRadioButton *auditRadioButton;
	QRadioButton *dmesgRadioButton;
	QCheckBox *lastreloadCheckBox;
	QCheckBox *requiresCheckBox;
	QCheckBox *referenceCheckBox;
	QCheckBox *verboseCheckBox;
	QCheckBox *explainCheckBox;
	QLineEdit *passwordLineEdit;
	QTextEdit *textEdit1;
	QPushButton *audit2allowButton;
	QPushButton *closeButton;
};

#endif
